@@ -1,17 +1,18 @@
-#' Ping urls to time requests
+#' httping
 #'
-#' @import httr
-#' @importFrom methods is
-#' @importFrom stats setNames
-#' @importFrom jsonlite fromJSON
-#' @importFrom pryr object_size
-#' @name httping-package
-#' @aliases httping
-#' @docType package
-#' @author Scott Chamberlain \email{myrmecocystus@@gmail.com}
-#' @keywords package
+#' Ping urls to time requests
 #'
 #' @section Pipes:
 #' You can use this function with or without pipes. We export the pipe
 #' \code{\%>\%} in this package so you don't have to load it separately.
+#'
+#' @keywords internal
+"_PACKAGE"
+
+## usethis namespace: start
+#' @import httr
+#' @importFrom methods is
+#' @importFrom stats setNames
+#' @importFrom jsonlite fromJSON
+## usethis namespace: end
 NULL
