@@ -26,13 +26,13 @@
 #' # ping("9200")
 #' }
 
-ping <- function(url, verb=GET, ...) {
+ping <- function(url, verb = GET, ...) {
   res <- verb(as.url(url)[[1]], ...)
   structure(list(status = res$status_code, request = res), class = "http_ping")
 }
 
 #' @export
-print.http_ping <- function(x, ...){
+print.http_ping <- function(x, ...) {
   vv <- httpcode::http_code(x$status)
   cat(paste0("<http ping> ", x$status), sep = "\n")
   cat(paste0("  Message: ", vv$message), sep = "\n")
@@ -42,9 +42,9 @@ print.http_ping <- function(x, ...){
 as.url <- function(x) UseMethod("as.url")
 as.url.url <- function(x) x
 as.url.character <- function(x) {
-  if ( is_url(x) ) {
+  if (is_url(x)) {
     x <- add_http(x)
-  } else if ( is_port(x) ) {
+  } else if (is_port(x)) {
     x <- paste0("http://localhost:", x)
   } else {
     stop("url or port not detected", call. = FALSE)
@@ -53,12 +53,13 @@ as.url.character <- function(x) {
 }
 as.url.numeric <- function(x) as.url(as.character(x))
 
-is_url <- function(x){
-  grepl("https?://", x, ignore.case = TRUE) || grepl("localhost:[0-9]{4}", x, ignore.case = TRUE)
+is_url <- function(x) {
+  grepl("https?://", x, ignore.case = TRUE) ||
+    grepl("localhost:[0-9]{4}", x, ignore.case = TRUE)
 }
 
 is_port <- function(x) grepl("[[:digit:]]", x) && nchar(x) == 4
 
-add_http <- function(x){
-  if ( !grepl("https?://", x, ignore.case = TRUE) ) paste0("http://", x) else x
+add_http <- function(x) {
+  if (!grepl("https?://", x, ignore.case = TRUE)) paste0("http://", x) else x
 }
