@@ -3,17 +3,21 @@ context("ping")
 test_that("ping works", {
   skip_on_cran()
 
-  aa1 <- "https://mockbin.com/request" %>% ping()
-  aa2 <- ping("https://mockbin.com/request")
-  bb1 <- "https://mockbin.com/request" %>% ping(config = timeout(1))
-  bb2 <- ping("https://mockbin.com/request", config = timeout(1))
-  cc <- "https://mockbin.com/request" %>% ping(config = accept_json())
+  httpbin <- webfakes::local_app_process(webfakes::httpbin_app())
+  url <- httpbin$url("/get")
+
+  aa1 <- url %>% ping()
+  aa2 <- ping(url)
+  bb1 <- url %>% ping(config = timeout(1))
+  bb2 <- ping(url, config = timeout(1))
+  cc <- url %>% ping(config = accept_json())
 
   expect_is(aa1, "http_ping")
   expect_is(aa2, "http_ping")
   expect_named(aa1$request$request$options, c('useragent', 'httpget'))
 
   aa1req <- httr::content(aa1$request)
+  aa1req$headers$`x-forwarded-for` <- NULL
   aa1req$headers$`connect-time` <- NULL
   aa1req$headers$`x-request-id` <- NULL
   aa1req$headers$`cf-ray` <- NULL
@@ -24,6 +28,7 @@ test_that("ping works", {
   aa1req$headersSize <- NULL
 
   aa2req <- httr::content(aa2$request)
+  aa2req$headers$`x-forwarded-for` <- NULL
   aa2req$headers$`connect-time` <- NULL
   aa2req$headers$`x-request-id` <- NULL
   aa2req$headers$`cf-ray` <- NULL
@@ -35,13 +40,15 @@ test_that("ping works", {
 
   expect_identical(aa1req, aa2req)
 
-
-
   expect_is(bb1, "http_ping")
   expect_is(bb2, "http_ping")
-  expect_named(bb1$request$request$options, c('useragent', 'timeout_ms', 'httpget'))
+  expect_named(
+    bb1$request$request$options,
+    c('useragent', 'timeout_ms', 'httpget')
+  )
 
   bb1req <- httr::content(bb1$request)
+  bb1req$headers$`x-forwarded-for` <- NULL
   bb1req$headers$`connect-time` <- NULL
   bb1req$headers$`x-request-id` <- NULL
   bb1req$headers$`cookie` <- NULL
@@ -50,6 +57,7 @@ test_that("ping works", {
   bb1req$startedDateTime <- NULL
 
   bb2req <- httr::content(bb2$request)
+  bb2req$headers$`x-forwarded-for` <- NULL
   bb2req$headers$`connect-time` <- NULL
   bb2req$headers$`x-request-id` <- NULL
   bb2req$headers$`cookie` <- NULL
@@ -60,17 +68,17 @@ test_that("ping works", {
   expect_identical(bb1req, bb2req)
 })
 
-test_that("ping - different HTTP verbse work", {
+test_that("ping - different HTTP verbs work", {
   skip_on_cran()
 
-  mb <- "https://mockbin.com/request"
+  httpbin <- webfakes::local_app_process(webfakes::httpbin_app())
 
-  aa <- mb %>% ping(verb = GET)
-  bb <- mb %>% ping(verb = HEAD)
-  cc <- mb %>% ping(verb = PUT)
-  dd <- mb %>% ping(verb = DELETE)
-  ee <- mb %>% ping(verb = PATCH)
-  ff <- mb %>% ping(verb = POST)
+  aa <- httpbin$url("/get") %>% ping(verb = GET)
+  bb <- httpbin$url("/get") %>% ping(verb = HEAD)
+  cc <- httpbin$url("/put") %>% ping(verb = PUT)
+  dd <- httpbin$url("/delete") %>% ping(verb = DELETE)
+  ee <- httpbin$url("/patch") %>% ping(verb = PATCH)
+  ff <- httpbin$url("/post") %>% ping(verb = POST)
 
   expect_is(aa, "http_ping")
   expect_is(aa$request, "response")
@@ -81,7 +89,7 @@ test_that("ping - different HTTP verbse work", {
 
   expect_is(cc, "http_ping")
   expect_is(cc$request, "response")
-  expect_equal(content(cc$request)$url, mb)
+  expect_equal(content(cc$request)$url, httpbin$url("/put"))
 
   expect_is(dd, "http_ping")
   expect_is(dd$request, "response")
